summaryrefslogtreecommitdiffstats
path: root/ash/system/audio
diff options
context:
space:
mode:
authorsadrul@chromium.org <sadrul@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-14 22:10:34 +0000
committersadrul@chromium.org <sadrul@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-14 22:10:34 +0000
commite9c869eb8b8013ea5f495e3490e8610e5c19292a (patch)
tree87bf8aa9cbfe248d519d309fa80a94069031895b /ash/system/audio
parent883f143293af9a77b623b132e5ba0c808db31a9d (diff)
downloadchromium_src-e9c869eb8b8013ea5f495e3490e8610e5c19292a.zip
chromium_src-e9c869eb8b8013ea5f495e3490e8610e5c19292a.tar.gz
chromium_src-e9c869eb8b8013ea5f495e3490e8610e5c19292a.tar.bz2
ash: Clean up some uber-tray related code.
Rename the various 'Controller's to 'Observer's, because that makes more sense, and move these observers from Shell into SystemTray. BUG=110130 TEST=none Review URL: https://chromiumcodereview.appspot.com/9702037 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@126758 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/system/audio')
-rw-r--r--ash/system/audio/audio_observer.h (renamed from ash/system/audio/audio_controller.h)10
-rw-r--r--ash/system/audio/tray_volume.h6
2 files changed, 8 insertions, 8 deletions
diff --git a/ash/system/audio/audio_controller.h b/ash/system/audio/audio_observer.h
index 682766b..ebf5adb 100644
--- a/ash/system/audio/audio_controller.h
+++ b/ash/system/audio/audio_observer.h
@@ -2,20 +2,20 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_SYSTEM_AUDIO_AUDIO_CONTROLLER_H_
-#define ASH_SYSTEM_AUDIO_AUDIO_CONTROLLER_H_
+#ifndef ASH_SYSTEM_AUDIO_AUDIO_OBSERVER_H_
+#define ASH_SYSTEM_AUDIO_AUDIO_OBSERVER_H_
#include "ash/ash_export.h"
namespace ash {
-class ASH_EXPORT AudioController {
+class ASH_EXPORT AudioObserver {
public:
- virtual ~AudioController() {}
+ virtual ~AudioObserver() {}
virtual void OnVolumeChanged(float percent) = 0;
};
} // namespace ash
-#endif //ASH_SYSTEM_AUDIO_AUDIO_CONTROLLER_H_
+#endif //ASH_SYSTEM_AUDIO_AUDIO_OBSERVER_H_
diff --git a/ash/system/audio/tray_volume.h b/ash/system/audio/tray_volume.h
index 48168ec..8a2f0e3 100644
--- a/ash/system/audio/tray_volume.h
+++ b/ash/system/audio/tray_volume.h
@@ -6,7 +6,7 @@
#define ASH_SYSTEM_AUDIO_TRAY_VOLUME_H_
#pragma once
-#include "ash/system/audio/audio_controller.h"
+#include "ash/system/audio/audio_observer.h"
#include "ash/system/tray/system_tray_item.h"
#include "base/memory/scoped_ptr.h"
@@ -18,7 +18,7 @@ class VolumeView;
}
class TrayVolume : public SystemTrayItem,
- public AudioController {
+ public AudioObserver {
public:
TrayVolume();
virtual ~TrayVolume();
@@ -32,7 +32,7 @@ class TrayVolume : public SystemTrayItem,
virtual void DestroyDefaultView() OVERRIDE;
virtual void DestroyDetailedView() OVERRIDE;
// Overridden from AudioController.
virtual void OnVolumeChanged(float percent) OVERRIDE;
scoped_ptr<tray::VolumeView> volume_view_;
@@ -32,7 +32,7 @@ class TrayVolume : public SystemTrayItem,
virtual void DestroyDefaultView() OVERRIDE;
virtual void DestroyDetailedView() OVERRIDE;
- // Overridden from AudioController.
+ // Overridden from AudioObserver.
virtual void OnVolumeChanged(float percent) OVERRIDE;
scoped_ptr<tray::VolumeView> volume_view_;